@@ -210,6 +210,9 @@ STREAMING if non-nil, turn on response streaming."
 (cl-defmethod llm-name ((provider llm-ollama))
   (llm-ollama-chat-model provider))
 
+(cl-defmethod llm-chat-token-limit ((provider llm-ollama))
+  (llm-provider-utils-model-token-limit (llm-ollama-chat-model provider)))
+
 (provide 'llm-ollama)
 
 ;;; llm-ollama.el ends here
