@@ -69,7 +69,7 @@ https://api.example.com/v1/chat, then URL should be
   "Return the request to the server for the embedding of STRING.
 MODEL is the embedding model to use, or nil to use the default.."
   `(("input" . ,string)
-    ("model" . ,(or model "text-embedding-ada-002"))))
+    ("model" . ,(or model "text-embedding-3-small"))))
 
 (defun llm-openai--embedding-extract-response (response)
   "Return the embedding from the server RESPONSE."
@@ -113,7 +113,7 @@ This is just the key, if it exists."
             "/") command))
 
 (cl-defmethod llm-embedding-async ((provider llm-openai) string vector-callback error-callback)
-  (llm-openai--check-key provider)
+  (llm-openai--check-key provider)  
   (let ((buf (current-buffer)))
     (llm-request-async (llm-openai--url provider "embeddings")
                        :headers (llm-openai--headers provider)
@@ -268,6 +268,27 @@ them from 1 to however many are sent.")
 (cl-defmethod llm-name ((_ llm-openai))
   "Open AI")
 
+;; See https://platform.openai.com/docs/models/gpt-4-and-gpt-4-turbo
+;; and https://platform.openai.com/docs/models/gpt-3-5.
+(cl-defmethod llm-chat-token-limit ((provider llm-openai))
+  (let ((model (llm-openai-chat-model provider)))
+    (cond
+     ((string-match (rx (seq (or ?- ?_) (group-n 1 (+ digit)) ?k)) model)
+      (let ((n (string-to-number (match-string 1 model))))
+        ;; This looks weird but Open AI really has an extra token for 16k
+        ;; models, but not for 32k models.
+        (+ (* n 1024) (if (= n 16) 1 0))))
+     ((equal model "gpt-4") 8192)
+     ((string-match-p (rx (seq "gpt-4-" (+ ascii) "-preview")) model)
+       128000)
+     ((string-match-p (rx (seq "gpt-4-" (+ digit))) model)
+      8192)
+     ((string-match-p (rx (seq "gpt-3.5-turbo-1" (+ digit))) model)
+      16385)
+     ((string-match-p (rx (seq "gpt-3.5-turbo" (opt "-instruct"))) model)
+      4096)
+     (t 4096))))
+
 (provide 'llm-openai)
 
 ;;; llm-openai.el ends here
